@@ -1,7 +1,7 @@
 package Taskwarrior::Kusarigama::Core;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Set of core functions interacting with Taskwarrior
-$Taskwarrior::Kusarigama::Core::VERSION = '0.1.0';
+$Taskwarrior::Kusarigama::Core::VERSION = '0.2.0';
 
 use strict;
 use warnings;
@@ -27,11 +27,51 @@ has $_ => (
 ) for  qw/ api version args command rc data /;
 
 
+has pre_command_args => sub {
+    my $self = shift;
+    my $command = $self->command;
+
+    my $args = $self->args;
+    $args =~ s/^task\s+//;
+
+    while() {
+        return $1 if $args =~ /(.*?)\s*\b$command\b/;
+
+        # command can be abbreviated
+        chop $command;
+    }
+
+};
+
+
+has post_command_args => sub {
+    my $self = shift;
+    my $command = $self->command;
+
+    my $args = $self->args;
+    $args =~ s/^task\s+//;
+
+    while() {
+        return $1 if $args =~ /\b$command\b\s*(.*)/;
+
+        # command can be abbreviated
+        chop $command;
+    }
+
+};
+
+
 has data_dir => sub {
     path( $_[0]->data );
 };
 
 
+has run_task => sub {
+    require Taskwarrior::Kusarigama::Wrapper;
+    Taskwarrior::Kusarigama::Wrapper->new;
+};
+
+
 has plugins => sub {
     my $self = shift;
     
@@ -92,7 +132,7 @@ Taskwarrior::Kusarigama::Core - Set of core functions interacting with Taskwarri
 
 =head1 VERSION
 
-version 0.1.0
+version 0.2.0
 
 =head1 DESCRIPTION
 
@@ -114,8 +154,37 @@ The role provides the following methods:
 
 =head2 data
 
+=head2 pre_command_args
+
+Returns the arguments that preceding the command as a string.
+
+    # assuming `task this and that foo` was run, and the command is 'foo'
+
+    $tw->pre_command_args; # => 'this and that'
+
+Note that because the way the hooks get the arguments, there is no way to
+distinguish between
+
+    task 'this and that' foo
+
+and
+
+    task this and that foo
+
+=head2 post_command_args
+
+Returns the arguments that follow the command as a string.
+
+    # assuming `task this and that foo sumfin` was run, and the command is 'foo'
+
+    $tw->post_command_args; # => 'sumfin'
+
 =head2 data_dir
 
+=head2 run_task
+
+Returns a L<Taskwarrior::Kusarigama::Wrapper> object.
+
 =head2 plugins
 
 Returns an arrayref of instances of the plugins defined 
